# History

## Roadmap

- Offline DBLP
- Customized collaboration graphs
  - Colors and size
  - Groups

## 0.2.1 (2025-09-01): Minor VisJS enhancements

- Better handling of dark/light mode (should be compatible with Pydata, Jupyter, and System).
- Responsive size


## 0.2.0 (2025-08-31): EgoMaps!

- New lab structure: EgoMap shows the people that revolves around you!
- New lab method: expansion, which adds *moons* (neighbor reasearchers).
- Add filters when building authors and publications.
- Physic engine changed fo better visualization.
- Multi-source handling fine-tuned.
- Better display (size and theme).


## 0.1.0 (2025-07-24): First release

- First release on PyPI.
- Online DBLP and HAL DB implemented.
- Lab stuctures implemented.
- Early version of collaboration graph available.
